crush
=====

`crush
<http://http://libcrush.org/main/python-crush>`_ is a
:ref:`GPLv3+ Licensed <gplv3>` library to control placement in a hierarchy.

Installation
------------

* pip install crush

Contributor Guide
-----------------

If you want to contribute to ``crush``, this part of the documentation is for
you.

.. toctree::
   :maxdepth: 1

   dev/authors
